/******************************************************************************
 * FILE
 *    uc_spc574k72_spec.h
 *
 * UC ARCHITECTURE:
 *    PowerPC
 *
 * UC FAMILY:
 *    SPC57
 *
 * DESCRIPTION
 *    Configuration and description of uC derivative.
 *    Parameters are taken from uC Datasheet and Reference manual.
 *
 * FILE HISTORY:
 *    V1.0    23.09.2017     RO
 *       > Initial version
 *    V2.0    25.01.2018     RO
 *       > file header update
 *    V3.0    30.01.2018     MF
 *       > file update for SPC574K72
 *
 ******************************************************************************
 * Copyright (C) 2015-2018 HighTec EDV-Systeme GmbH.  All rights reserved.
 *
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/

#ifndef UC_SPC574K72_SPEC_H_
#define UC_SPC574K72_SPEC_H_

/* Signal that uC derivative description exists */
#define UC_SPC57XX_FOUND          1

/* Include vendor provided uC derivative register header file */
#include "ST/spc574k2_cut2.3.h"

/* uC specific types needed in BSP API interface */
#include "uc_spc574k72_types.h"

/* Get uC configurable parameters */
#include "uc_spc574k72_cfg.h"

/* ============================================================================
 * uC MODULE INSTANCES IMPLEMENTATION
 * Only relevant modules for BSP support package
 * ==========================================================================*/

/* Mode Entry module */
#define UC_MODULE_ME              1

/* Interrupt module */
#define UC_MODULE_INTC            1

/* PLL modules */
#define UC_MODULE_PLL0            1
#define UC_MODULE_PLL1            1

/* Platform FLASH controllers */
#define UC_MODULE_PFLASH0         1
#define UC_MODULE_PFLASH1         0

/* Platform SRAM controllers */
#define UC_MODULE_PRAM0           1
#define UC_MODULE_PRAM1           0
#define UC_MODULE_PRAM2           0
#define UC_MODULE_PRAM3           0

/* Watchdog modules */
#define UC_MODULE_SWT0            1
#define UC_MODULE_SWT1            0
#define UC_MODULE_SWT2            1
#define UC_MODULE_SWT3            1

/* SIUL IO interface */
#define UC_MODULE_SIUL            1

/* PIT0 Timer module */
#define UC_MODULE_PIT0            1

/* SYSCLK Outputs */
#define UC_MODULE_SYSCLK0         1
#define UC_MODULE_SYSCLK1         1

/* CLOCK Generation module */
#define UC_MODULE_CGM             1

/* SC DC Dividers */
#define UC_MODULE_CGM_SC          0
#define UC_MODULE_CGM_SC_DC0      1  /* CORE0_CLK */
#define UC_MODULE_CGM_SC_DC1      1  /* CORE2_CLK, Slow XBAR */
#define UC_MODULE_CGM_SC_DC2      1  /* PBRIDGEA_CLK, PBRIDGEB_CLK */
#define UC_MODULE_CGM_SC_DC3      0  
#define UC_MODULE_CGM_SC_DC4      0  
#define UC_MODULE_CGM_SC_DC5      0  

/* AC0 CLOCK Bridge */
#define UC_MODULE_CGM_AC0         1
#define UC_MODULE_CGM_AC0_DC0     1  /* PER_CLK */
#define UC_MODULE_CGM_AC0_DC1     1  /* SDADC_CLK */
#define UC_MODULE_CGM_AC0_DC2     1  /* SARADC_CLK */
#define UC_MODULE_CGM_AC0_DC3     1  /* DSPI_CLK0 (DSPI_4/5) */
#define UC_MODULE_CGM_AC0_DC4     1  /* DSPI_CLK1 (DSPI_0/1/2), LIN_CLK */
#define UC_MODULE_CGM_AC0_DC5     0

/* AC1 CLOCK Bridge */
#define UC_MODULE_CGM_AC1         1
#define UC_MODULE_CGM_AC1_DC0     1  /* RF REF DRCLK, BD LFAST PLL, PD LFAST PLL */
#define UC_MODULE_CGM_AC1_DC1     0
#define UC_MODULE_CGM_AC1_DC2     0
#define UC_MODULE_CGM_AC1_DC3     0
#define UC_MODULE_CGM_AC1_DC4     0
#define UC_MODULE_CGM_AC1_DC5     0

/* AC2 CLOCK Bridge */
#define UC_MODULE_CGM_AC2         0
#define UC_MODULE_CGM_AC2_DC0     1  /* FRAY_CLK */
#define UC_MODULE_CGM_AC2_DC1     1  /* SENT_CLK*/
#define UC_MODULE_CGM_AC2_DC2     0
#define UC_MODULE_CGM_AC2_DC3     0
#define UC_MODULE_CGM_AC2_DC4     0
#define UC_MODULE_CGM_AC2_DC5     0

/* AC3 CLOCK Bridge */
#define UC_MODULE_CGM_AC3         1  /* PLL0 Clock Selection */
#define UC_MODULE_CGM_AC3_DC0     0
#define UC_MODULE_CGM_AC3_DC1     0
#define UC_MODULE_CGM_AC3_DC2     0
#define UC_MODULE_CGM_AC3_DC3     0
#define UC_MODULE_CGM_AC3_DC4     0
#define UC_MODULE_CGM_AC3_DC5     0

/* AC4 CLOCK Bridge */
#define UC_MODULE_CGM_AC4         1 /* PLL1 Clock Selection */
#define UC_MODULE_CGM_AC4_DC0     0
#define UC_MODULE_CGM_AC4_DC1     0
#define UC_MODULE_CGM_AC4_DC2     0
#define UC_MODULE_CGM_AC4_DC3     0
#define UC_MODULE_CGM_AC4_DC4     0
#define UC_MODULE_CGM_AC4_DC5     0

/* AC5 CLOCK Bridge */
#define UC_MODULE_CGM_AC5         0
#define UC_MODULE_CGM_AC5_DC0     1  /* PSI5_f189 */
#define UC_MODULE_CGM_AC5_DC1     1  /* PSI5_f125 */
#define UC_MODULE_CGM_AC5_DC2     1  /* PSI5_1us */
#define UC_MODULE_CGM_AC5_DC3     0
#define UC_MODULE_CGM_AC5_DC4     0
#define UC_MODULE_CGM_AC5_DC5     0

/* AC6 CLOCK Bridge */
#define UC_MODULE_CGM_AC6         1
#define UC_MODULE_CGM_AC6_DC0     1  /* SYSCLK0 Output */
#define UC_MODULE_CGM_AC6_DC1     0
#define UC_MODULE_CGM_AC6_DC2     0
#define UC_MODULE_CGM_AC6_DC3     0
#define UC_MODULE_CGM_AC6_DC4     0
#define UC_MODULE_CGM_AC6_DC5     0

/* AC7 CLOCK Bridge */
#define UC_MODULE_CGM_AC7         1
#define UC_MODULE_CGM_AC7_DC0     1  /* SYSCLK1 Output */
#define UC_MODULE_CGM_AC7_DC1     0
#define UC_MODULE_CGM_AC7_DC2     0
#define UC_MODULE_CGM_AC7_DC3     0
#define UC_MODULE_CGM_AC7_DC4     0
#define UC_MODULE_CGM_AC7_DC5     0

/* AC8 CLOCK Bridge */
#define UC_MODULE_CGM_AC8         1
#define UC_MODULE_CGM_AC8_DC0     1  /* CAN_CLK */
#define UC_MODULE_CGM_AC8_DC1     0
#define UC_MODULE_CGM_AC8_DC2     0
#define UC_MODULE_CGM_AC8_DC3     0
#define UC_MODULE_CGM_AC8_DC4     0
#define UC_MODULE_CGM_AC8_DC5     0

/* AC9 CLOCK Bridge */
#define UC_MODULE_CGM_AC9         1
#define UC_MODULE_CGM_AC9_DC0     1  /* RTI_CLK */
#define UC_MODULE_CGM_AC9_DC1     0
#define UC_MODULE_CGM_AC9_DC2     0
#define UC_MODULE_CGM_AC9_DC3     0
#define UC_MODULE_CGM_AC9_DC4     0
#define UC_MODULE_CGM_AC9_DC5     0

/* AC10 CLOCK Bridge */
#define UC_MODULE_CGM_AC10        1
#define UC_MODULE_CGM_AC10_DC0    1	 /*FEC_REF_CLK*/
#define UC_MODULE_CGM_AC10_DC1    0
#define UC_MODULE_CGM_AC10_DC2    0
#define UC_MODULE_CGM_AC10_DC3    0
#define UC_MODULE_CGM_AC10_DC4    0
#define UC_MODULE_CGM_AC10_DC5    0

/* AC11 CLOCK Bridge */
#define UC_MODULE_CGM_AC11        0
#define UC_MODULE_CGM_AC11_DC0    0
#define UC_MODULE_CGM_AC11_DC1    0
#define UC_MODULE_CGM_AC11_DC2    0
#define UC_MODULE_CGM_AC11_DC3    0
#define UC_MODULE_CGM_AC11_DC4    0
#define UC_MODULE_CGM_AC11_DC5    0

/* AC12 CLOCK Bridge */
#define UC_MODULE_CGM_AC12        0
#define UC_MODULE_CGM_AC12_DC0    0
#define UC_MODULE_CGM_AC12_DC1    0
#define UC_MODULE_CGM_AC12_DC2    0
#define UC_MODULE_CGM_AC12_DC3    0
#define UC_MODULE_CGM_AC12_DC4    0
#define UC_MODULE_CGM_AC12_DC5    0


/* ============================================================================
 * CORES SPECIFICATION
 * ==========================================================================*/

/* Number of Cores instances */
#define UC_CORE_MAX               2

/* RESET CORE: core that starts after Power On */
#define UC_RESET_CORE             2

/* CORE Enable register indexes (in register ME_CCTL, ME_CADDR) */
#define UC_CORE0_START_ID         1
#define UC_CORE2_START_ID         0

/* Core0 (Main_0) Cache implementation */
#define UC_CORE0_ICHACHE          1
#define UC_CORE0_DCHACHE          0

/* Core2 (IOP) Cache implementation */
#define UC_CORE2_ICHACHE          0
#define UC_CORE2_DCHACHE          0

/* ============================================================================
 * CLOCK SPECIFICATION
 * ==========================================================================*/

/* Internal oscillator value [MHz] */
#define UC_IRCOSC_CLOCK           16

/* SYSTEM_CLOCK_MAX: maximum frequency for the cores [MHz]
 * RM Chapter 26 Clocking - 26.3 System Clock Limitations */
#define UC_SYSTEM_CLOCK_MAX       160

/* AUX CLOCK_MAX: maximum input frequency for AUX bridges [MHz]
 * RM Chapter 26 Clocking - 26.3 System Clock Limitations */
#define UC_PLL0_PHI_CLOCK_MAX     400

/* SRAM CLOCK_MAX: limit that requires additional read wait state [MHz]
 * RM - Chapter 7 Device Configuration - 7.5.1.1 PRAM Wait State Management */
#define UC_SRAM_CLOCK_MAX         160

/* ----------------------------------------------------------------------------
 * CGM SC DC MAX CLOCKS (System)
 * RM Chapter 25 Clocking - 25.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_SC_DC0) /* CORE0_CLK */
#define UC_CGM_SC_DC0_MAX_CLOCK   160
#endif

#if (UC_MODULE_CGM_SC_DC1) /* CORE2_CLK, Slow XBAR */
#define UC_CGM_SC_DC1_MAX_CLOCK   80
#endif

#if (UC_MODULE_CGM_SC_DC2) /* PBRIDGEA_CLK, PBRIDGEB_CLK */
#define UC_CGM_SC_DC2_MAX_CLOCK   80
#endif


/* ----------------------------------------------------------------------------
 * CGM AC0 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 26 Clocking - 26.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC0)
#define UC_CGM_AC0_MIN_CLOCK      0
#define UC_CGM_AC0_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC0_DC0) /* PER_CLK */
#define UC_CGM_AC0_DC0_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC0_DC1) /* SDADC */
#define UC_CGM_AC0_DC1_MAX_CLOCK  16
#endif

#if (UC_MODULE_CGM_AC0_DC2) /* SARADC */
#define UC_CGM_AC0_DC2_MAX_CLOCK  16
#endif

#if (UC_MODULE_CGM_AC0_DC3) /* DSPI_CLK0 */
#define UC_CGM_AC0_DC3_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC0_DC4) /* DSPI_CLK1 */
#define UC_CGM_AC0_DC4_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC0_DC5)
#error Forgotten AC0 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC1 & DC MAX CLOCKS (Peripherals)
 * DS Chapter 3.13.3 LFAST PLL electrical characteristics
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1)
#define UC_CGM_AC1_MIN_CLOCK      0
#define UC_CGM_AC1_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC1_DC0) /* LFAST PLL */
#define UC_CGM_AC1_DC0_MAX_CLOCK  26
#endif

#if (UC_MODULE_CGM_AC1_DC1 || \
     UC_MODULE_CGM_AC1_DC2 || \
	 UC_MODULE_CGM_AC1_DC3 || \
     UC_MODULE_CGM_AC1_DC4 || \
     UC_MODULE_CGM_AC1_DC5)
#error Forgotten AC1 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC2 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 26 Clocking - 26.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2)
#define UC_CGM_AC2_MIN_CLOCK      0
#define UC_CGM_AC2_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC2_DC0) /* FRAY */
#define UC_CGM_AC2_DC0_MAX_CLOCK  50
#endif

#if (UC_MODULE_CGM_AC2_DC1) /* SENT */
#define UC_CGM_AC2_DC1_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC2_DC2 || \
	 UC_MODULE_CGM_AC2_DC3 || \
     UC_MODULE_CGM_AC2_DC4 || \
     UC_MODULE_CGM_AC2_DC5)
#error Forgotten AC2 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC3 & DC MAX CLOCKS (Peripherals)
 * DS Chapter 3.10.1 FMPLL
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3)                /* PLL_0 */
#define UC_CGM_AC3_MIN_CLOCK      8
#define UC_CGM_AC3_MAX_CLOCK      44
#endif

#if (UC_MODULE_CGM_AC3_DC0 || \
     UC_MODULE_CGM_AC3_DC1 || \
     UC_MODULE_CGM_AC3_DC2 || \
	 UC_MODULE_CGM_AC3_DC3 || \
     UC_MODULE_CGM_AC3_DC4 || \
     UC_MODULE_CGM_AC3_DC5)
#error Forgotten AC3 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC4 & DC MAX CLOCKS (Peripherals)
 * DS 3.10.1 FMPLL
 * ----------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4)                /* PLL_1 */
#define UC_CGM_AC4_MIN_CLOCK      38
#define UC_CGM_AC4_MAX_CLOCK      78
#endif

#if (UC_MODULE_CGM_AC4_DC0 || \
     UC_MODULE_CGM_AC4_DC1 || \
     UC_MODULE_CGM_AC4_DC2 || \
	 UC_MODULE_CGM_AC4_DC3 || \
     UC_MODULE_CGM_AC4_DC4 || \
     UC_MODULE_CGM_AC4_DC5)
#error Forgotten AC4 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC5 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 26.6.1 PSI5 clock dividers
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5)
#define UC_CGM_AC5_MIN_CLOCK      0
#define UC_CGM_AC5_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC5_DC0) /* PSI5_f189 */
#define UC_CGM_AC5_DC0_MAX_CLOCK  6.048
#endif

#if (UC_MODULE_CGM_AC5_DC1) /* PSI5_f125 */
#define UC_CGM_AC5_DC1_MAX_CLOCK  4
#endif

#if (UC_MODULE_CGM_AC5_DC2) /* PSI5_1us */
#define UC_CGM_AC5_DC2_MAX_CLOCK  1
#endif

#if (UC_MODULE_CGM_AC5_DC3 || \
     UC_MODULE_CGM_AC5_DC4 || \
     UC_MODULE_CGM_AC5_DC5)
#error Forgotten AC5 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC6 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 26 Clocking - 26.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6)
#define UC_CGM_AC6_MIN_CLOCK      0
#define UC_CGM_AC6_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC6_DC0) /* SYSCLK0 */
#define UC_CGM_AC6_DC0_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC6_DC1 || \
     UC_MODULE_CGM_AC6_DC2 || \
	 UC_MODULE_CGM_AC6_DC3 || \
     UC_MODULE_CGM_AC6_DC4 || \
     UC_MODULE_CGM_AC6_DC5)
#error Forgotten AC6 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC7 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 26 Clocking - 26.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7)
#define UC_CGM_AC7_MIN_CLOCK      0
#define UC_CGM_AC7_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC7_DC0) /* SYSCLK1 */
#define UC_CGM_AC7_DC0_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC7_DC1 || \
     UC_MODULE_CGM_AC7_DC2 || \
	 UC_MODULE_CGM_AC7_DC3 || \
     UC_MODULE_CGM_AC7_DC4 || \
     UC_MODULE_CGM_AC7_DC5)
#error Forgotten AC7 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC8 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 26 Clocking - 26.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8)
#define UC_CGM_AC8_MIN_CLOCK      0
#define UC_CGM_AC8_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC8_DC0) /* CAN_CLK0 (for CCCU=Disabled) */
#define UC_CGM_AC8_DC0_MAX_CLOCK  80
#endif

#if (UC_MODULE_CGM_AC8_DC1 || \
     UC_MODULE_CGM_AC8_DC2 || \
	 UC_MODULE_CGM_AC8_DC3 || \
     UC_MODULE_CGM_AC8_DC4 || \
     UC_MODULE_CGM_AC8_DC5)
#error Forgotten AC8 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC9 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 7.8.3.4 PIT/RTI clocking
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9)
#define UC_CGM_AC9_MIN_CLOCK      0
#define UC_CGM_AC9_MAX_CLOCK      40
#endif

#if (UC_MODULE_CGM_AC9_DC0) /* RTI */
#define UC_CGM_AC9_DC0_MAX_CLOCK  40
#endif

#if (UC_MODULE_CGM_AC9_DC1 || \
     UC_MODULE_CGM_AC9_DC2 || \
	 UC_MODULE_CGM_AC9_DC3 || \
     UC_MODULE_CGM_AC9_DC4 || \
     UC_MODULE_CGM_AC9_DC5)
#error Forgotten AC9 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC10 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC10)
#define UC_CGM_AC10_MIN_CLOCK      0
#define UC_CGM_AC10_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC10_DC0) /* FEC_REF_CLK */
#define UC_CGM_AC10_DC0_MAX_CLOCK  50
#endif

#if (UC_MODULE_CGM_AC10_DC1 || \
     UC_MODULE_CGM_AC10_DC2 || \
	 UC_MODULE_CGM_AC10_DC3 || \
     UC_MODULE_CGM_AC10_DC4 || \
     UC_MODULE_CGM_AC10_DC5)
#error Forgotten AC10 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC11 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 26 Clocking - 26.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC11)
#define UC_CGM_AC11_MIN_CLOCK      0
#define UC_CGM_AC11_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC11_DC0 || \
	 UC_MODULE_CGM_AC11_DC1 || \
	 UC_MODULE_CGM_AC11_DC2 || \
	 UC_MODULE_CGM_AC11_DC3 || \
     UC_MODULE_CGM_AC11_DC4 || \
     UC_MODULE_CGM_AC11_DC5)
#error Forgotten AC11 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC12 & DC MAX CLOCKS (Peripherals)
 * RM Chapter 27 Clocking - 27.3 System Clock Limitations
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12)
#define UC_CGM_AC12_MIN_CLOCK      0
#define UC_CGM_AC12_MAX_CLOCK      400
#endif

#if (UC_MODULE_CGM_AC12_DC0 || \
	 UC_MODULE_CGM_AC12_DC1 || \
	 UC_MODULE_CGM_AC12_DC2 || \
	 UC_MODULE_CGM_AC12_DC3 || \
     UC_MODULE_CGM_AC12_DC4 || \
     UC_MODULE_CGM_AC12_DC5)
#error Forgotten AC12 DCx MAX Clock definition
#endif

/* ----------------------------------------------------------------------------
 * CGM SC DC MAX DIVIDERS (System)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_SC_DC0)
#define UC_CGM_SC_DC0_MAX_DIV     64
#endif

#if (UC_MODULE_CGM_SC_DC1)
#define UC_CGM_SC_DC1_MAX_DIV     64
#endif

#if (UC_MODULE_CGM_SC_DC2)
#define UC_CGM_SC_DC2_MAX_DIV     64
#endif

/* ----------------------------------------------------------------------------
 * CGM AC0 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * RM Chapter 29.3.1.24 Auxiliary Clock 0 Divider 3 Configuration Register
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC0_DC0) /* PER_CLK */
#define UC_CGM_AC0_DC0_MAX_DIV    16
#endif

#if (UC_MODULE_CGM_AC0_DC1) /* SDADC */
#define UC_CGM_AC0_DC1_MAX_DIV    128
#endif

#if (UC_MODULE_CGM_AC0_DC2) /* SARADC */
#define UC_CGM_AC0_DC2_MAX_DIV    128
#endif

#if (UC_MODULE_CGM_AC0_DC3) /* DSPI 4/5 */
#define UC_CGM_AC0_DC3_MAX_DIV    512
#endif

#if (UC_MODULE_CGM_AC0_DC4) /* DSPI 1/2/3 */
#define UC_CGM_AC0_DC4_MAX_DIV    16
#endif

#if (UC_MODULE_CGM_AC0_DC5)
#error Forgotten AC0 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC1 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1_DC0) /* RF_LFLASH_PLL */
#define UC_CGM_AC1_DC0_MAX_DIV    128
#endif

#if (UC_MODULE_CGM_AC1_DC1 || \
     UC_MODULE_CGM_AC1_DC2 || \
	 UC_MODULE_CGM_AC1_DC3 || \
     UC_MODULE_CGM_AC1_DC4 || \
     UC_MODULE_CGM_AC1_DC5)
#error Forgotten AC1 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC2 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2_DC0) /* FRAY_CKL */
#define UC_CGM_AC2_DC0_MAX_DIV    64
#endif

#if (UC_MODULE_CGM_AC2_DC1) /* SENT */
#define UC_CGM_AC2_DC1_MAX_DIV    64
#endif

#if (UC_MODULE_CGM_AC2_DC2 || \
	 UC_MODULE_CGM_AC2_DC3 || \
     UC_MODULE_CGM_AC2_DC4 || \
     UC_MODULE_CGM_AC2_DC5)
#error Forgotten AC2 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC3 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3_DC0 || \
     UC_MODULE_CGM_AC3_DC1 || \
     UC_MODULE_CGM_AC3_DC2 || \
	 UC_MODULE_CGM_AC3_DC3 || \
     UC_MODULE_CGM_AC3_DC4 || \
     UC_MODULE_CGM_AC3_DC5)
#error Forgotten AC3 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC4 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 27 Clocking - 30.3.1 DCx Register description
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4_DC0 || \
     UC_MODULE_CGM_AC4_DC1 || \
     UC_MODULE_CGM_AC4_DC2 || \
	 UC_MODULE_CGM_AC4_DC3 || \
     UC_MODULE_CGM_AC4_DC4 || \
     UC_MODULE_CGM_AC4_DC5)
#error Forgotten AC4 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC5 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * RM Chapter 29.3.1.35 Auxiliary Clock 5 Divider 0 Configuration Register
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5_DC0) /* PSI5_f189 */
#define UC_CGM_AC5_DC0_MAX_DIV    8192
#endif

#if (UC_MODULE_CGM_AC5_DC1) /* PSI5_f125 */
#define UC_CGM_AC5_DC1_MAX_DIV    256
#endif

#if (UC_MODULE_CGM_AC5_DC2) /* PSI5_1us */
#define UC_CGM_AC5_DC2_MAX_DIV    1024
#endif

#if (UC_MODULE_CGM_AC5_DC3 || \
     UC_MODULE_CGM_AC5_DC4 || \
     UC_MODULE_CGM_AC5_DC5)
#error Forgotten AC5 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC6 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6_DC0) /* SYSCLK0 */
#define UC_CGM_AC6_DC0_MAX_DIV    512
#endif

#if (UC_MODULE_CGM_AC6_DC1 || \
     UC_MODULE_CGM_AC6_DC2 || \
	 UC_MODULE_CGM_AC6_DC3 || \
     UC_MODULE_CGM_AC6_DC4 || \
     UC_MODULE_CGM_AC6_DC5)
#error Forgotten AC6 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC7 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7_DC0) /* SYSCLK1 */
#define UC_CGM_AC7_DC0_MAX_DIV    512
#endif

#if (UC_MODULE_CGM_AC7_DC1 || \
     UC_MODULE_CGM_AC7_DC2 || \
	 UC_MODULE_CGM_AC7_DC3 || \
     UC_MODULE_CGM_AC7_DC4 || \
     UC_MODULE_CGM_AC7_DC5)
#error Forgotten AC7 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC8 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8_DC0) /* CAN_CLK0 (for CCCU=Disabled) */
#define UC_CGM_AC8_DC0_MAX_DIV    64
#endif

#if (UC_MODULE_CGM_AC8_DC1 || \
     UC_MODULE_CGM_AC8_DC2 || \
	 UC_MODULE_CGM_AC8_DC3 || \
     UC_MODULE_CGM_AC8_DC4 || \
     UC_MODULE_CGM_AC8_DC5)
#error Forgotten AC8 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC9 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9_DC0) /* RTI */
#define UC_CGM_AC9_DC0_MAX_DIV    64
#endif

#if (UC_MODULE_CGM_AC9_DC1 || \
     UC_MODULE_CGM_AC9_DC2 || \
	 UC_MODULE_CGM_AC9_DC3 || \
     UC_MODULE_CGM_AC9_DC4 || \
     UC_MODULE_CGM_AC9_DC5)
#error Forgotten AC9 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC10 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC10_DC0) /* FEC_REF_CLK */
#define UC_CGM_AC10_DC0_MAX_DIV    16
#endif

#if (UC_MODULE_CGM_AC10_DC1 || \
     UC_MODULE_CGM_AC10_DC2 || \
	 UC_MODULE_CGM_AC10_DC3 || \
     UC_MODULE_CGM_AC10_DC4 || \
     UC_MODULE_CGM_AC10_DC5)
#error Forgotten AC10 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC11 DC MAX DIVIDERS (Peripherals)
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC11_DC0 || \
	 UC_MODULE_CGM_AC11_DC1 || \
	 UC_MODULE_CGM_AC11_DC2 || \
	 UC_MODULE_CGM_AC11_DC3 || \
     UC_MODULE_CGM_AC11_DC4 || \
     UC_MODULE_CGM_AC11_DC5)
#error Forgotten AC11 DCx MAX divider definition
#endif

/* ----------------------------------------------------------------------------
 * CGM AC12 DC MAX DIVIDERS
 * RM Chapter 26.2 Clock generation, Figure 248. Clock generation
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12_DC0 || \
	 UC_MODULE_CGM_AC12_DC1 || \
	 UC_MODULE_CGM_AC12_DC2 || \
	 UC_MODULE_CGM_AC12_DC3 || \
     UC_MODULE_CGM_AC12_DC4 || \
     UC_MODULE_CGM_AC12_DC5)
#error Forgotten AC12 DCx MAX divider definition
#endif


/* ============================================================================
 * SYSCLK0 OUTPUT SPECIFICATION
 * ==========================================================================*/

#if (UC_MODULE_SYSCLK0)

/* AUX selection, only when there is a choice */
#if defined(UC_SYSCLK0_SEL)
#define UC_SYSCLK0_AUX            6
#endif

/* Divider index either on AUX_DC or SC_DC */
#define UC_SYSCLK0_DC             0
#define UC_SYSCLK0_DIV_MAX        UC_CGM_AC6_DC0_MAX_DIV

/* SYSCLK0 output pin (PORT_F:Pin_8) */
#define UC_SYSCLK0_PIN            88

#endif


/* ============================================================================
 * SYSCLK1 OUTPUT SPECIFICATION
 * ==========================================================================*/

#if (UC_MODULE_SYSCLK1)

/* AUX selection, delete this symbol, if it is fixed on SC */
#if defined(UC_SYSCLK1_SEL)
#define UC_SYSCLK1_AUX            7
#endif

/* Divider index either on AUX_DC or SC_DC */
#define UC_SYSCLK1_DC             0
#define UC_SYSCLK1_DIV_MAX        UC_CGM_AC7_DC0_MAX_DIV

/* SYSCLK1 output pin (PORT_A:Pin_15 */
#define UC_SYSCLK1_PIN            15

#endif


/* ============================================================================
 * PFLASH SPECIFICATION
 * ==========================================================================*/

/* PFLASH selection of minimum Wait states for given SYSTEM_CLOCK
 * DS Chapter 3.16 - Flash Memory */
#define UC_PFLASH_5_WS_CLOCK      160
#define UC_PFLASH_4_WS_CLOCK      140
#define UC_PFLASH_3_WS_CLOCK      110
#define UC_PFLASH_2_WS_CLOCK      80
#define UC_PFLASH_1_WS_CLOCK      50
#define UC_PFLASH_0_WS_CLOCK      25


/* PFLASH minimum wait states needed based on SYSTEM_CLOCK setting */
#if (UC_SYSTEM_CLOCK > UC_PFLASH_4_WS_CLOCK)
#define UC_PFLASH_WS_MIN  5
#elif (UC_SYSTEM_CLOCK > UC_PFLASH_3_WS_CLOCK)
#define UC_PFLASH_WS_MIN  4
#elif (UC_SYSTEM_CLOCK > UC_PFLASH_2_WS_CLOCK)
#define UC_PFLASH_WS_MIN  3
#elif (UC_SYSTEM_CLOCK > UC_PFLASH_1_WS_CLOCK)
#define UC_PFLASH_WS_MIN  2
#elif (UC_SYSTEM_CLOCK > UC_PFLASH_0_WS_CLOCK)
#define UC_PFLASH_WS_MIN  1
#else
#define UC_PFLASH_WS_MIN  0
#endif


/* ============================================================================
 * PRAM SPECIFICATION
 * ==========================================================================*/

/* SRAM 1 Wait states for Read access */
#define UC_PRAM_FT_DIS           0


/* ============================================================================
 * PLL0 SPECIFICATION
 * ==========================================================================*/

#if (UC_MODULE_PLL0)

/* PLL0 parameters
 * DS Chapter 3.10.1 - PLL0 */
#define UC_PLL0_INCLK_MIN         8
#define UC_PLL0_INCLK_MAX         44
#define UC_PLL0_VCO_MIN           600
#define UC_PLL0_VCO_MAX           1250

/* PLL0 DV register boundaries 
 * DS Chapter 27.5.2.3 PLL0 Divider Register (PLL0DV)*/
#define UC_PLL0_MFD_MIN            8
#define UC_PLL0_MFD_MAX            127

#endif


/* ============================================================================
 * PLL1 SPECIFICATION
 * ==========================================================================*/

#if (UC_MODULE_PLL1)

/* PLL1 parameters
 * DS Chapter 3.10.1 FMPLL */
#define UC_PLL1_INCLK_MIN         37
#define UC_PLL1_INCLK_MAX         78
#define UC_PLL1_VCO_MIN           600
#define UC_PLL1_VCO_MAX           1250

/* PLL1 DV register boundaries */
#define UC_PLL1_MFD_MIN            16
#define UC_PLL1_MFD_MAX            34

#endif


/* ============================================================================
 * PIT SPECIFICATION
 * ==========================================================================*/

/* Number of channel instances for PIT_0 */
#define UC_MODULE_PIT_CHANNELS    6

/* PIT Timer Channel 0 ISR Vector (base vector for subsequent channels) 
 * RM Chapter 7.3.7.3 Interrupt sources */
#define UC_PIT_CH0_ISR_VECTOR     226


/* ============================================================================
 * MODULE BASE ADDRESSES IN MEMORY MAP
 * use of semiconductor peripheral file
 * ==========================================================================*/

#if (UC_MODULE_ME)
#define UC_ME_BASE                (uint32_t) &MC_ME
#endif

#if (UC_MODULE_INTC)
#define UC_INTC                   (uint32_t) &INTC
#endif

#if (UC_MODULE_CGM)
#define UC_CGM                    (uint32_t) &MC_CGM
#endif

#if (UC_MODULE_PLL0 | UC_MODULE_PLL1)
#define UC_PLL_BASE               (uint32_t) &PLLDIG
#endif

#if (UC_MODULE_PFLASH0)
#define	UC_PFLASH0_BASE           (uint32_t) &PFLASH
#endif

#if (UC_MODULE_PFLASH1)
#define	UC_PFLASH1_BASE           (uint32_t) &PFLASH_1
#endif

#if (UC_MODULE_PRAM0)
#define	UC_PRAM0_BASE             (uint32_t) &PRAM
#endif

#if (UC_MODULE_PRAM1)
#define	UC_PRAM1_BASE             (uint32_t) &PRAM_1
#endif

#if (UC_MODULE_PRAM2)
#define	UC_PRAM2_BASE             (uint32_t) &PRAM_2
#endif

#if (UC_MODULE_PRAM3)
#define	UC_PRAM3_BASE             (uint32_t) &PRAM_3
#endif

#if (UC_MODULE_SWT0)
#define UC_SWT0_BASE              (uint32_t) &SWT_0
#endif

#if (UC_MODULE_SWT1)
#define UC_SWT1_BASE              (uint32_t) &SWT_1
#endif

#if (UC_MODULE_SWT2)
#define UC_SWT2_BASE              (uint32_t) &SWT_2
#endif

#if (UC_MODULE_SWT3)
#define UC_SWT3_BASE              (uint32_t) &SWT_3
#endif

#if (UC_MODULE_PIT0)
#define	UC_PIT0_BASE              (uint32_t) &PIT_0
#endif

#if (UC_MODULE_SIUL)
#define UC_SIUL_BASE              (uint32_t) &SIUL2
#endif


/* ============================================================================
 * PLL SUBSYSTEM CALCULATION
 * ==========================================================================*/

/* ----------------------------------------------------------------------------
 * PLL1 CALCULATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PLL1)

/* Selection of PLL1_IN_CLOCK generated from PLL0
 * 40 MHz : allows going to lower system clock frequency setting
 * */

#define UC_PLL1_IN_CLOCK          60

/* PLL1 MIN values to make following macros readable */
#define PLL1_VCO_MIN (UC_PLL1_VCO_MIN-1)
#define PLL1_VCO_MAX (UC_PLL1_VCO_MAX+1)
#define PLL1_MFD_MIN (UC_PLL1_MFD_MIN-1)

/* PLL1 parameters
 * 3 default PLL1 configurations that should fit most of the SYSTEM_CLOCK.
 * If not, than the USer must provide its own HW platform initialization and
 * switch off the default configuration by defining BSP_HW_INIT_CHECK=0 */

/* PLL1_VCO_A : RFPDHI = 6 */
#define PLL1_VCO_A                (UC_SYSTEM_CLOCK * 6)
#define PLL1_MFD_A                (PLL1_VCO_A / UC_PLL1_IN_CLOCK)
#define PLL1_MFD_A_NOT_VALID      ((PLL1_MFD_A * UC_PLL1_IN_CLOCK)-PLL1_VCO_A)
#if ( (PLL1_VCO_A < PLL1_VCO_MAX) && (PLL1_VCO_A > PLL1_VCO_MIN) && (PLL1_MFD_A > PLL1_MFD_MIN) && !PLL1_MFD_A_NOT_VALID )
#define PLL1_RFDPHI               6
#define PLL1_MFD                  PLL1_MFD_A

#else /* PLL1_VCO_A not valid, try PLL1_VCO_B : RFDPHI = 12 */
#define PLL1_VCO_B                (UC_SYSTEM_CLOCK * 12)
#define PLL1_MFD_B                (PLL1_VCO_B / UC_PLL1_IN_CLOCK)
#define PLL1_MFD_B_NOT_VALID      ((PLL1_MFD_B * UC_PLL1_IN_CLOCK)-PLL1_VCO_B)
#if ( (PLL1_VCO_B < PLL1_VCO_MAX) && (PLL1_VCO_B > PLL1_VCO_MIN) && (PLL1_MFD_B > PLL1_MFD_MIN) && !PLL1_MFD_B_NOT_VALID )
#define PLL1_RFDPHI               12
#define PLL1_MFD                  PLL1_MFD_B

#else /* PLL1_VCO_B not valid, try PLL1_VCO_C : RFDPHI = 24*/
#define PLL1_VCO_C                (UC_SYSTEM_CLOCK * 24)
#define PLL1_MFD_C                (PLL1_VCO_C / UC_PLL1_IN_CLOCK)
#define PLL1_MFD_C_NOT_VALID      ((PLL1_MFD_C * UC_PLL1_IN_CLOCK)-PLL1_VCO_C)
#if ( (PLL1_VCO_C < PLL1_VCO_MAX) && (PLL1_VCO_C > PLL1_VCO_MIN) && (PLL1_MFD_C > PLL1_MFD_MIN) && !PLL1_MFD_C_NOT_VALID )
#define PLL1_RFDPHI               24
#define PLL1_MFD                  PLL1_MFD_C

#else /* Simple algorithm has not found a solution */
#if (BSP_HW_INIT_CHECK)
#error PLL1 setting cannot be found, try different combination of SYSTEM_CLOCK and AUX_CLOCK, \
	   or switch off the default BSP HW initialization and implement \
       your own HW initialization (use directly LLD API)
#endif /* #if BSP_HW_INIT_CHECK */

#endif /* PLL1_VCO_C */
#endif /* PLL1_VCO_B */
#endif /* PLL1_VCO_A */

#endif /* UC_MODULE_PLL1 */

/* ----------------------------------------------------------------------------
 * PLL0 CALCULATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PLL0)

/* PLL0 MIN values to make following macros more readable */
#define PLL0_VCO_MIN              (UC_PLL0_VCO_MIN - 1)
#define PLL0_VCO_MAX              (UC_PLL0_VCO_MAX)

/* Direct setting, they should be within uC parameters limits by any case */
#define PLL0_RFDPHI1              12
#define PLL0_VCO                  (PLL0_RFDPHI1 * UC_PLL1_IN_CLOCK)
#define PLL0_RFDPHI               (PLL0_VCO / UC_PLL0_PHI_CLOCK)
#define PLL0_MFD                  (PLL0_VCO / UC_XTAL_CLOCK)
#define PLL0_PREDIV               1

/* Check PLL0 VCO frequency */
#if ((PLL0_VCO > PLL0_VCO_MAX) || (PLL0_VCO < PLL0_VCO_MIN))
#error PLL0 VCO is out of the range
#endif
/* Check RFDPHI setting, if it is a whole integer */
#if ((PLL0_RFDPHI * UC_PLL0_PHI_CLOCK) - PLL0_VCO)
#error PLL0 clock setting is not exact, check is needed
#endif

/* PLL0 parameters setting */
#define UC_PLL0_PREDIV            PLL0_PREDIV
#define UC_PLL0_MFD               PLL0_MFD
#define UC_PLL0_RFDPHI            PLL0_RFDPHI
#define UC_PLL0_RFDPHI1           PLL0_RFDPHI1

#endif


/* ============================================================================
 * PLATFORM CONFIGURATION
 * Optimal platform setting for configured clocks
 * ==========================================================================*/

/* Desired System clock selection from UC_ME_MODE_SYSCLK_e */
#define UC_SYSTEM_CLOCK_SEL       UC_ME_MODE_SYSCLK_PLL1_PHI


/* ----------------------------------------------------------------------------
 * PLL0 CONFIGURATION
 * calculated ones
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PLL0)

#define UC_PLL0_PREDIV            PLL0_PREDIV
#define UC_PLL0_MFD               PLL0_MFD
#define UC_PLL0_RFDPHI            PLL0_RFDPHI
#define UC_PLL0_RFDPHI1           PLL0_RFDPHI1

#endif

/* ----------------------------------------------------------------------------
 * PLL1 CONFIGURATION
 * calculated ones
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PLL1)

#define UC_PLL1_MFD               PLL1_MFD
#define UC_PLL1_RFDPHI            PLL1_RFDPHI

#endif

/* ----------------------------------------------------------------------------
 * PFLASH0 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PFLASH0)

/* PFCR1 */
#define UC_PFLASH0_PFCR1_APC      UC_PFLASH_APC_PIPELINE_DIS
#define UC_PFLASH0_PFCR1_WS       UC_PFLASH_WS_MIN
#define UC_PFLASH0_PFCR1_PFLIM    UC_PFLASH_PFLIM_ON_MISS

/* PFCR2 */
#define UC_PFLASH0_PFCR2_PFLIM    UC_PFLASH_PFLIM_ON_MISS

/* PFCR3 */
#define UC_PFLASH0_PFCR3_P0WCFG   UC_PFLASH_WCFG_NO_PARTITIONING
#define UC_PFLASH0_PFCR3_P1WCFG   UC_PFLASH_WCFG_NO_PARTITIONING
#define UC_PFLASH0_PFCR3_ARB      UC_PFLASH_ARBM_FIXED_PRIO_P0_P1

#endif

/* ----------------------------------------------------------------------------
 * PFLASH1 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PFLASH1)

/* PFCR1 */
#define UC_PFLASH1_PFCR1_APC      UC_PFLASH_APC_PIPELINE_DIS
#define UC_PFLASH1_PFCR1_WS       UC_PFLASH_WS_MIN
#define UC_PFLASH1_PFCR1_PFLIM    UC_PFLASH_PFLIM_ON_MISS

/* PFCR2 */
#define UC_PFLASH1_PFCR2_PFLIM    UC_PFLASH_PFLIM_ON_MISS

/* PFCR3 */
#define UC_PFLASH1_PFCR3_P0WCFG   UC_PFLASH_WCFG_NO_PARTITIONING
#define UC_PFLASH1_PFCR3_P1WCFG   UC_PFLASH_WCFG_NO_PARTITIONING
#define UC_PFLASH1_PFCR3_ARB      UC_PFLASH_ARBM_FIXED_PRIO_P0_P1

#endif

/* ----------------------------------------------------------------------------
 * PRAM0 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PRAM0)

#define UC_PRAM0_PFCR1_PRI        UC_PRAM_PRI_P0_P1
#define UC_PRAM0_PFCR1_P0RB       UC_PRAM_RB_ENABLE
#define UC_PRAM0_PFCR1_P1RB       UC_PRAM_RB_ENABLE
#define UC_PRAM0_PFCR1_FTDIS      UC_PRAM_FT_DIS

#endif

/* ----------------------------------------------------------------------------
 * PRAM1 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PRAM1)

#define UC_PRAM1_PFCR1_PRI        UC_PRAM_PRI_P0_P1
#define UC_PRAM1_PFCR1_P0RB       UC_PRAM_RB_ENABLE
#define UC_PRAM1_PFCR1_P1RB       UC_PRAM_RB_ENABLE
#define UC_PRAM1_PFCR1_FTDIS      UC_PRAM_FT_DIS

#endif

/* ----------------------------------------------------------------------------
 * PRAM2 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PRAM2)

#define UC_PRAM2_PFCR1_PRI        UC_PRAM_PRI_P0_P1
#define UC_PRAM2_PFCR1_P0RB       UC_PRAM_RB_ENABLE
#define UC_PRAM2_PFCR1_P1RB       UC_PRAM_RB_ENABLE
#define UC_PRAM2_PFCR1_FTDIS      UC_PRAM_FT_DIS

#endif

/* ----------------------------------------------------------------------------
 * PRAM3 CONFIGURATION
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_PRAM3)

#define UC_PRAM3_PFCR1_PRI        UC_PRAM_PRI_P0_P1
#define UC_PRAM3_PFCR1_P0RB       UC_PRAM_RB_ENABLE
#define UC_PRAM3_PFCR1_P1RB       UC_PRAM_RB_ENABLE
#define UC_PRAM3_PFCR1_FTDIS      UC_PRAM_FT_DIS

#endif

/* ----------------------------------------------------------------------------
 * CGM CLOCK AUX BRIDGES CONFIGURATION
 * --------------------------------------------------------------------------*/

/* System clock dividers - Fast clock */
#if ((UC_SYSTEM_CLOCK > UC_XTAL_CLOCK) || (UC_SYSTEM_CLOCK > UC_IRCOSC_CLOCK))
#define UC_CGM_CORE_CLK_DIV       1
#define UC_CGM_IOP_CLK_DIV        2
#define UC_CGM_PBRIDGE_CLK_DIV    4
#define UC_CGM_FBRIDGE_CLK_DIV    1
#if (UC_SYSTEM_CLOCK > UC_CGM_SC_DC4_FAST_CLOCK)
#define UC_CGM_PFBRIDGE_CLK_DIV   2
#else
#define UC_CGM_PFBRIDGE_CLK_DIV   1
#endif
#define UC_CGM_HSM_CLK_DIV        2

/* System clock dividers - Slow clock */
#else
#define UC_CGM_CORE_CLK_DIV       1
#define UC_CGM_HPBM_CLK_DIV       1
#define UC_CGM_PBRIDGE_CLK_DIV    1
#define UC_CGM_FBRIDGE_CLK_DIV    1
#define UC_CGM_PFBRIDGE_CLK_DIV   1
#define UC_CGM_HSM_CLK_DIV        2
#endif

/* Peripheral clock dividers */
#define UC_PER_CLK0_DIV           (UC_PLL0_PHI_CLOCK / UC_PER_CLK0)
#define UC_SDADC_CLK_DIV          (UC_PLL0_PHI_CLOCK / UC_SDADC_CLK)
#define UC_SARADC_CLK_DIV         (UC_PLL0_PHI_CLOCK / UC_SARADC_CLK)
#define UC_DSPI_CLK0_DIV          (UC_PLL0_PHI_CLOCK / UC_DSPI_CLK0)
#define UC_DSPI_CLK1_DIV          (UC_PLL0_PHI_CLOCK / UC_DSPI_CLK1)
#define UC_RF_REF_CLK_DIV         (UC_PLL0_PHI_CLOCK / UC_RF_REF_CLK)
#define UC_FRAY_CLK_DIV           (UC_PLL0_PHI_CLOCK / UC_FRAY_CLK)
#define UC_SENT_CLK_DIV           (UC_PLL0_PHI_CLOCK / UC_SENT_CLK)
#define UC_CAN_CLK0_DIV           (UC_PLL0_PHI_CLOCK / UC_CAN_CLK0)
#define UC_RTI_CLK0_DIV           (UC_PLL0_PHI_CLOCK / UC_RTI_CLK0)


/* AC Clock Selection - one common group */
#define UC_CGM_AC_CLKSEL_IRCOSC        0
#define UC_CGM_AC_CLKSEL_XOSC          1
#define UC_CGM_AC_CLKSEL_PLL0_PHI      2
#define UC_CGM_AC_CLKSEL_PLL0_PHI1     3
#define UC_CGM_AC_CLKSEL_PLL1_PHI      4
#define UC_CGM_AC_CLKSEL_LFAST_PIN     5

/* ----------------------------------------------------------------------------
 * SC DC
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_SC_DC0) /* CORE0_CLK */
#define UC_CGM_SC_DC0_INIT       1
#define UC_CGM_SC_DC0_DIV        UC_CGM_CORE_CLK_DIV
#endif

#if (UC_MODULE_CGM_SC_DC1) /* IOP_CLK, SXBAR_CLK */
#define UC_CGM_SC_DC1_INIT       1
#define UC_CGM_SC_DC1_DIV        UC_CGM_IOP_CLK_DIV
#endif

#if (UC_MODULE_CGM_SC_DC2) /* PBRIDGEA_CLK, PBRIDGEA_CLK */
#define UC_CGM_SC_DC2_INIT       1
#define UC_CGM_SC_DC2_DIV        UC_CGM_PBRIDGE_CLK_DIV
#endif

#if (UC_MODULE_CGM_SC_DC3 || \
     UC_MODULE_CGM_SC_DC4 || \
     UC_MODULE_CGM_SC_DC5)
#error Forgotten initialization of AC0 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC0
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC0)
#define UC_CGM_AC0_INIT           1
#define UC_CGM_AC0_CLOCK_INPUT    UC_CGM_AC_CLKSEL_PLL0_PHI
#define UC_CGM_AC0_CLOCK_VALUE    UC_PLL0_PHI_CLOCK
#endif

#if (UC_MODULE_CGM_AC0_DC0) /* PER_CLK */
#define UC_CGM_AC0_DC0_INIT       1
#define UC_CGM_AC0_DC0_DIV        UC_PER_CLK0_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC1) /* SDADC_CLK */
#define UC_CGM_AC0_DC1_INIT       1
#define UC_CGM_AC0_DC1_DIV        UC_SDADC_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC2) /* SARADC_CLK */
#define UC_CGM_AC0_DC2_INIT       1
#define UC_CGM_AC0_DC2_DIV        UC_SARADC_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC3) /* DSPI_CLK0 (DSPI_4/5) */
#define UC_CGM_AC0_DC3_INIT       1
#define UC_CGM_AC0_DC3_DIV        UC_DSPI_CLK0_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC4) /* DSPI_CLK1 (DSPI_0/1/2), LIN_CLK */
#define UC_CGM_AC0_DC4_INIT       1
#define UC_CGM_AC0_DC4_DIV        UC_DSPI_CLK1_DIV
#endif

#if (UC_MODULE_CGM_AC0_DC5)
#error Forgotten initialization of AC0 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC1
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1)
#define UC_CGM_AC1_INIT           0
#define UC_CGM_AC1_CLOCK_INPUT    0
#define UC_CGM_AC1_CLOCK_VALUE    0
#endif

#if (UC_MODULE_CGM_AC1_DC0) /* LFAST */
#define UC_CGM_AC1_DC0_INIT       0
#define UC_CGM_AC1_DC0_DIV        0
#endif

#if (UC_MODULE_CGM_AC1_DC1 || \
     UC_MODULE_CGM_AC1_DC2 || \
	 UC_MODULE_CGM_AC1_DC3 || \
     UC_MODULE_CGM_AC1_DC4 || \
	 UC_MODULE_CGM_AC1_DC5)
#error Forgotten initialization of AC1 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC2
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2)
#error Forgotten initialization of AC2 clock selector
#endif

#if (UC_MODULE_CGM_AC2_DC0) /* FRAY */
#define UC_CGM_AC2_DC0_INIT       1
#define UC_CGM_AC2_DC0_DIV        UC_FRAY_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC2_DC1) /* SENT */
#define UC_CGM_AC2_DC1_INIT       1
#define UC_CGM_AC2_DC1_DIV        UC_SENT_CLK_DIV
#endif

#if (UC_MODULE_CGM_AC2_DC2 || \
	 UC_MODULE_CGM_AC2_DC3 || \
     UC_MODULE_CGM_AC2_DC4 || \
	 UC_MODULE_CGM_AC2_DC5)
#error Forgotten initialization of AC1 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC3
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3) /* PLL0 */
#define UC_CGM_AC3_INIT           1
#define UC_CGM_AC3_CLOCK_INPUT    UC_CGM_AC_CLKSEL_XOSC
#define UC_CGM_AC3_CLOCK_VALUE    UC_XTAL_CLOCK
#endif

#if (UC_MODULE_CGM_AC3_DC0 || \
     UC_MODULE_CGM_AC3_DC1 || \
     UC_MODULE_CGM_AC3_DC2 || \
	 UC_MODULE_CGM_AC3_DC3 || \
     UC_MODULE_CGM_AC3_DC4 || \
	 UC_MODULE_CGM_AC3_DC5)
#error Forgotten initialization of AC3 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC4
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4) /* PLL1 */
#define UC_CGM_AC4_INIT           1
#define UC_CGM_AC4_CLOCK_INPUT    UC_CGM_AC_CLKSEL_PLL0_PHI1
#define UC_CGM_AC4_CLOCK_VALUE    UC_PLL1_IN_CLOCK
#endif

#if (UC_MODULE_CGM_AC4_DC0 || \
     UC_MODULE_CGM_AC4_DC1 || \
     UC_MODULE_CGM_AC4_DC2 || \
	 UC_MODULE_CGM_AC4_DC3 || \
     UC_MODULE_CGM_AC4_DC4 || \
	 UC_MODULE_CGM_AC4_DC5)
#error Forgotten initialization of AC4 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC5
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5) /* PSI5 (not supported by current BSP) */
#define UC_CGM_AC5_INIT           0
#define UC_CGM_AC5_CLOCK_INPUT    0
#define UC_CGM_AC5_CLOCK_VALUE    0
#endif

#if (UC_MODULE_CGM_AC5_DC0)
#define UC_CGM_AC5_DC0_INIT       0
#define UC_CGM_AC5_DC0_DIV        0
#endif

#if (UC_MODULE_CGM_AC5_DC1)
#define UC_CGM_AC5_DC1_INIT       0
#define UC_CGM_AC5_DC1_DIV        0
#endif

#if (UC_MODULE_CGM_AC5_DC2)
#define UC_CGM_AC5_DC2_INIT       0
#define UC_CGM_AC5_DC2_DIV        0
#endif

#if (UC_MODULE_CGM_AC5_DC3 || \
     UC_MODULE_CGM_AC5_DC4 || \
	 UC_MODULE_CGM_AC5_DC5)
#error Forgotten initialization of AC5 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC6
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6) /* SYSCLK0 (Not initialized by default) */
#define UC_CGM_AC6_INIT           0
#define UC_CGM_AC6_CLOCK_INPUT    0
#define UC_CGM_AC6_CLOCK_VALUE    0
#endif

#if (UC_MODULE_CGM_AC6_DC0)
#define UC_CGM_AC6_DC0_INIT       0
#define UC_CGM_AC6_DC0_DIV        0
#endif

#if (UC_MODULE_CGM_AC6_DC1 || \
     UC_MODULE_CGM_AC6_DC2 || \
	 UC_MODULE_CGM_AC6_DC3 || \
     UC_MODULE_CGM_AC6_DC4 || \
	 UC_MODULE_CGM_AC6_DC5)
#error Forgotten initialization of AC6 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC7
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7) /* SYSCLK1 (Not initialized by default) */
#define UC_CGM_AC7_INIT           0
#define UC_CGM_AC7_CLOCK_INPUT    0
#define UC_CGM_AC7_CLOCK_VALUE    0
#endif

#if (UC_MODULE_CGM_AC7_DC0)
#define UC_CGM_AC7_DC0_INIT       0
#define UC_CGM_AC7_DC0_DIV        0
#endif

#if (UC_MODULE_CGM_AC7_DC1 || \
     UC_MODULE_CGM_AC7_DC2 || \
	 UC_MODULE_CGM_AC7_DC3 || \
     UC_MODULE_CGM_AC7_DC4 || \
	 UC_MODULE_CGM_AC7_DC5)
#error Forgotten initialization of AC7 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC8
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8)
#define UC_CGM_AC8_INIT           1
#define UC_CGM_AC8_CLOCK_INPUT    UC_CGM_AC_CLKSEL_PLL0_PHI
#define UC_CGM_AC8_CLOCK_VALUE    UC_PLL0_PHI_CLOCK
#endif

#if (UC_MODULE_CGM_AC8_DC0) /* CAN_CLK0 */
#define UC_CGM_AC8_DC0_INIT       1
#define UC_CGM_AC8_DC0_DIV        UC_CAN_CLK0_DIV
#endif

#if (UC_MODULE_CGM_AC8_DC1 || \
     UC_MODULE_CGM_AC8_DC2 || \
	 UC_MODULE_CGM_AC8_DC3 || \
     UC_MODULE_CGM_AC8_DC4 || \
	 UC_MODULE_CGM_AC8_DC5)
#error Forgotten initialization of AC8 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC9
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9)
#define UC_CGM_AC9_INIT           0
#define UC_CGM_AC9_CLOCK_INPUT    0
#define UC_CGM_AC9_CLOCK_VALUE    0
#endif

#if (UC_MODULE_CGM_AC9_DC0) /* RTI_CLK */
#define UC_CGM_AC9_DC0_INIT       0
#define UC_CGM_AC9_DC0_DIV        0
#endif

#if (UC_MODULE_CGM_AC9_DC1 || \
     UC_MODULE_CGM_AC9_DC2 || \
	 UC_MODULE_CGM_AC9_DC3 || \
     UC_MODULE_CGM_AC9_DC4 || \
	 UC_MODULE_CGM_AC9_DC5)
#error Forgotten initialization of AC9 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC10
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC10)
#define UC_CGM_AC10_INIT           0
#define UC_CGM_AC10_CLOCK_INPUT    0
#define UC_CGM_AC10_CLOCK_VALUE    0
#endif

#if (UC_MODULE_CGM_AC10_DC0) /* FEC_REF_CLK */
#define UC_CGM_AC10_DC0_INIT       0
#define UC_CGM_AC10_DC0_DIV        0
#endif

#if (UC_MODULE_CGM_AC10_DC1 || \
     UC_MODULE_CGM_AC10_DC2 || \
	 UC_MODULE_CGM_AC10_DC3 || \
     UC_MODULE_CGM_AC10_DC4 || \
	 UC_MODULE_CGM_AC10_DC5)
#error Forgotten initialization of AC10 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC11
 * --------------------------------------------------------------------------*/
#if (UC_MODULE_CGM_AC11)
#error Forgotten initialization of AC11 Clock selection
#endif

#if (UC_MODULE_CGM_AC11_DC0 || \
     UC_MODULE_CGM_AC11_DC1 || \
     UC_MODULE_CGM_AC11_DC2 || \
	 UC_MODULE_CGM_AC11_DC3 || \
     UC_MODULE_CGM_AC11_DC4 || \
	 UC_MODULE_CGM_AC11_DC5)
#error Forgotten initialization of AC11 Dividers
#endif

/* ----------------------------------------------------------------------------
 * AC12
 * --------------------------------------------------------------------------*/
#if (UC_MODULE_CGM_AC12)
#error Forgotten initialization of AC12 Clock selection
#endif

#if (UC_MODULE_CGM_AC12_DC0 || \
     UC_MODULE_CGM_AC12_DC1 || \
     UC_MODULE_CGM_AC12_DC2 || \
	 UC_MODULE_CGM_AC12_DC3 || \
     UC_MODULE_CGM_AC12_DC4 || \
	 UC_MODULE_CGM_AC12_DC5)
#error Forgotten initialization of AC12 Dividers
#endif

/* ============================================================================
 * uC CONFIGURATION CHECKS
 * ==========================================================================*/

#if (BSP_HW_INIT_CHECK)

/* ----------------------------------------------------------------------------
 * SYSTEM CLOCKS
 * --------------------------------------------------------------------------*/

/* check of System Clock configuration */
#if (UC_SYSTEM_CLOCK > UC_SYSTEM_CLOCK_MAX)
#error SYS_CLOCK is higher than architecture maximum
#endif

/* check of AUX Clock configuration */
#if (UC_PLL0_PHI_CLOCK > UC_PLL0_PHI_CLOCK_MAX)
#error AUX_CLOCK is higher than architecture maximum
#endif

/* Check of XTAL range for PLL0 */
#if ((UC_XTAL_CLOCK < UC_PLL0_INCLK_MIN) || (UC_XTAL_CLOCK > UC_PLL0_INCLK_MAX))
#error XTAL_CLOCK setting is out of permitted boundary
#endif

/* ----------------------------------------------------------------------------
 * SYSCLK OUTPUTS
 * --------------------------------------------------------------------------*/

/* SYSCLK0 Divider maximum check */
#if (UC_SYSCLK0_DIV > UC_SYSCLK0_DIV_MAX)
#error SYSCLK0 divider > MAX
#endif

/* SYSCLK1 Divider maximum check */
#if (UC_SYSCLK1_DIV > UC_SYSCLK1_DIV_MAX)
#error SYSCLK1 divider > MAX
#endif

/* ----------------------------------------------------------------------------
 * SUPPORTED MODULE CLOCKS DIVIDERS
 * Dividers must be a whole integer to get precise
 * user specified clock
 * --------------------------------------------------------------------------*/

/* PER whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_PER_CLK0_DIV * UC_PER_CLK0))
#error GTM clock is not exact, divider is not a whole number. Check the setting
#endif

/* SDADC whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_SDADC_CLK_DIV * UC_SDADC_CLK))
#error SDADC clock is not exact, divider is not a whole number. Check the setting
#endif

/* SARADC whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_SARADC_CLK_DIV * UC_SARADC_CLK))
#error SARADC clock is not exact, divider is not a whole number. Check the setting
#endif

/* FRAY_CLK whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_FRAY_CLK_DIV * UC_FRAY_CLK))
#error FRAY clock is not exact, divider is not a whole number. Check the setting
#endif

/* SENT_CLK whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_SENT_CLK_DIV * UC_SENT_CLK))
#error SENT clock is not exact, divider is not a whole number. Check the setting
#endif

/* CAN CLOCK 0 - whole integer divider */
#if (UC_PLL0_PHI_CLOCK - (UC_CAN_CLK0_DIV * UC_CAN_CLK0))
#error CAN_CLK0 clock is not exact, divider is not a whole number. Check the setting
#endif

/* DSPI_CLK0 whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_DSPI_CLK0_DIV * UC_DSPI_CLK0))
#error DSPI_CLK0 clock is not exact, divider is not a whole number. Check the setting
#endif

/* DSPI_CLK1 whole integer divider check */
#if (UC_PLL0_PHI_CLOCK - (UC_DSPI_CLK1_DIV * UC_DSPI_CLK1))
#error DSPI_CLK1 clock is not exact, divider is not a whole number. Check the setting
#endif

/* ----------------------------------------------------------------------------
 * AC1 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1_DC0)
#if (UC_CGM_AC1_DC0_DIV > UC_CGM_AC1_DC0_MAX_DIV)
#error AC1_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC1)
#if (UC_CGM_AC1_DC1_DIV > UC_CGM_AC1_DC1_MAX_DIV)
#error AC1_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC2)
#if (UC_CGM_AC1_DC2_DIV > UC_CGM_AC1_DC2_MAX_DIV)
#error AC1_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC3)
#if (UC_CGM_AC1_DC3_DIV > UC_CGM_AC1_DC3_MAX_DIV)
#error AC1_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC4)
#if (UC_CGM_AC1_DC4_DIV > UC_CGM_AC1_DC4_MAX_DIV)
#error AC1_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC5)
#if (UC_CGM_AC1_DC5_DIV > UC_CGM_AC1_DC5_MAX_DIV)
#error AC1_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC2 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2_DC0)
#if (UC_CGM_AC2_DC0_DIV > UC_CGM_AC2_DC0_MAX_DIV)
#error AC2_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC1)
#if (UC_CGM_AC2_DC1_DIV > UC_CGM_AC2_DC1_MAX_DIV)
#error AC2_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC2)
#if (UC_CGM_AC2_DC2_DIV > UC_CGM_AC2_DC2_MAX_DIV)
#error AC2_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC3)
#if (UC_CGM_AC2_DC3_DIV > UC_CGM_AC2_DC3_MAX_DIV)
#error AC2_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC4)
#if (UC_CGM_AC2_DC4_DIV > UC_CGM_AC2_DC4_MAX_DIV)
#error AC2_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC5)
#if (UC_CGM_AC2_DC5_DIV > UC_CGM_AC2_DC5_MAX_DIV)
#error AC2_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC2 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2_DC0)
#if (UC_CGM_AC2_DC0_DIV > UC_CGM_AC2_DC0_MAX_DIV)
#error AC2_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC1)
#if (UC_CGM_AC2_DC1_DIV > UC_CGM_AC2_DC1_MAX_DIV)
#error AC2_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC2)
#if (UC_CGM_AC2_DC2_DIV > UC_CGM_AC2_DC2_MAX_DIV)
#error AC2_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC3)
#if (UC_CGM_AC2_DC3_DIV > UC_CGM_AC2_DC3_MAX_DIV)
#error AC2_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC4)
#if (UC_CGM_AC2_DC4_DIV > UC_CGM_AC2_DC4_MAX_DIV)
#error AC2_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC5)
#if (UC_CGM_AC2_DC5_DIV > UC_CGM_AC2_DC5_MAX_DIV)
#error AC2_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC3 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3_DC0)
#if (UC_CGM_AC3_DC0_DIV > UC_CGM_AC3_DC0_MAX_DIV)
#error AC3_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC1)
#if (UC_CGM_AC3_DC1_DIV > UC_CGM_AC3_DC1_MAX_DIV)
#error AC3_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC2)
#if (UC_CGM_AC3_DC2_DIV > UC_CGM_AC3_DC2_MAX_DIV)
#error AC3_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC3)
#if (UC_CGM_AC3_DC3_DIV > UC_CGM_AC3_DC3_MAX_DIV)
#error AC3_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC4)
#if (UC_CGM_AC3_DC4_DIV > UC_CGM_AC3_DC4_MAX_DIV)
#error AC3_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC5)
#if (UC_CGM_AC3_DC5_DIV > UC_CGM_AC3_DC5_MAX_DIV)
#error AC3_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC4 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4_DC0)
#if (UC_CGM_AC4_DC0_DIV > UC_CGM_AC4_DC0_MAX_DIV)
#error AC4_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC1)
#if (UC_CGM_AC4_DC1_DIV > UC_CGM_AC4_DC1_MAX_DIV)
#error AC4_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC2)
#if (UC_CGM_AC4_DC2_DIV > UC_CGM_AC4_DC2_MAX_DIV)
#error AC4_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC3)
#if (UC_CGM_AC4_DC3_DIV > UC_CGM_AC4_DC3_MAX_DIV)
#error AC4_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC4)
#if (UC_CGM_AC4_DC4_DIV > UC_CGM_AC4_DC4_MAX_DIV)
#error AC4_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC5)
#if (UC_CGM_AC4_DC5_DIV > UC_CGM_AC4_DC5_MAX_DIV)
#error AC4_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC5 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5_DC0)
#if (UC_CGM_AC5_DC0_DIV > UC_CGM_AC5_DC0_MAX_DIV)
#error AC5_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC1)
#if (UC_CGM_AC5_DC1_DIV > UC_CGM_AC5_DC1_MAX_DIV)
#error AC5_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC2)
#if (UC_CGM_AC5_DC2_DIV > UC_CGM_AC5_DC2_MAX_DIV)
#error AC5_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC3)
#if (UC_CGM_AC5_DC3_DIV > UC_CGM_AC5_DC3_MAX_DIV)
#error AC5_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC4)
#if (UC_CGM_AC5_DC4_DIV > UC_CGM_AC5_DC4_MAX_DIV)
#error AC5_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC5)
#if (UC_CGM_AC5_DC5_DIV > UC_CGM_AC5_DC5_MAX_DIV)
#error AC5_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC5 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5_DC0)
#if (UC_CGM_AC5_DC0_DIV > UC_CGM_AC5_DC0_MAX_DIV)
#error AC5_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC1)
#if (UC_CGM_AC5_DC1_DIV > UC_CGM_AC5_DC1_MAX_DIV)
#error AC5_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC2)
#if (UC_CGM_AC5_DC2_DIV > UC_CGM_AC5_DC2_MAX_DIV)
#error AC5_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC3)
#if (UC_CGM_AC5_DC3_DIV > UC_CGM_AC5_DC3_MAX_DIV)
#error AC5_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC4)
#if (UC_CGM_AC5_DC4_DIV > UC_CGM_AC5_DC4_MAX_DIV)
#error AC5_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC5)
#if (UC_CGM_AC5_DC5_DIV > UC_CGM_AC5_DC5_MAX_DIV)
#error AC5_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC6 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6_DC0)
#if (UC_CGM_AC6_DC0_DIV > UC_CGM_AC6_DC0_MAX_DIV)
#error AC6_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC1)
#if (UC_CGM_AC6_DC1_DIV > UC_CGM_AC6_DC1_MAX_DIV)
#error AC6_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC2)
#if (UC_CGM_AC6_DC2_DIV > UC_CGM_AC6_DC2_MAX_DIV)
#error AC6_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC3)
#if (UC_CGM_AC6_DC3_DIV > UC_CGM_AC6_DC3_MAX_DIV)
#error AC6_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC4)
#if (UC_CGM_AC6_DC4_DIV > UC_CGM_AC6_DC4_MAX_DIV)
#error AC6_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC5)
#if (UC_CGM_AC6_DC5_DIV > UC_CGM_AC6_DC5_MAX_DIV)
#error AC6_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC7 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7_DC0)
#if (UC_CGM_AC7_DC0_DIV > UC_CGM_AC7_DC0_MAX_DIV)
#error AC7_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC1)
#if (UC_CGM_AC7_DC1_DIV > UC_CGM_AC7_DC1_MAX_DIV)
#error AC7_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC2)
#if (UC_CGM_AC7_DC2_DIV > UC_CGM_AC7_DC2_MAX_DIV)
#error AC7_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC3)
#if (UC_CGM_AC7_DC3_DIV > UC_CGM_AC7_DC3_MAX_DIV)
#error AC7_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC4)
#if (UC_CGM_AC7_DC4_DIV > UC_CGM_AC7_DC4_MAX_DIV)
#error AC7_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC5)
#if (UC_CGM_AC7_DC5_DIV > UC_CGM_AC7_DC5_MAX_DIV)
#error AC7_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC8 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8_DC0)
#if (UC_CGM_AC8_DC0_DIV > UC_CGM_AC8_DC0_MAX_DIV)
#error AC8_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC1)
#if (UC_CGM_AC8_DC1_DIV > UC_CGM_AC8_DC1_MAX_DIV)
#error AC8_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC2)
#if (UC_CGM_AC8_DC2_DIV > UC_CGM_AC8_DC2_MAX_DIV)
#error AC8_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC3)
#if (UC_CGM_AC8_DC3_DIV > UC_CGM_AC8_DC3_MAX_DIV)
#error AC8_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC4)
#if (UC_CGM_AC8_DC4_DIV > UC_CGM_AC8_DC4_MAX_DIV)
#error AC8_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC5)
#if (UC_CGM_AC8_DC5_DIV > UC_CGM_AC8_DC5_MAX_DIV)
#error AC8_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC9 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9_DC0)
#if (UC_CGM_AC9_DC0_DIV > UC_CGM_AC9_DC0_MAX_DIV)
#error AC9_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC1)
#if (UC_CGM_AC9_DC1_DIV > UC_CGM_AC9_DC1_MAX_DIV)
#error AC9_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC2)
#if (UC_CGM_AC9_DC2_DIV > UC_CGM_AC9_DC2_MAX_DIV)
#error AC9_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC3)
#if (UC_CGM_AC9_DC3_DIV > UC_CGM_AC9_DC3_MAX_DIV)
#error AC9_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC4)
#if (UC_CGM_AC9_DC4_DIV > UC_CGM_AC9_DC4_MAX_DIV)
#error AC9_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC5)
#if (UC_CGM_AC9_DC5_DIV > UC_CGM_AC9_DC5_MAX_DIV)
#error AC9_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC1210 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1210_DC0)
#if (UC_CGM_AC1210_DC0_DIV > UC_CGM_AC1210_DC0_MAX_DIV)
#error AC1210_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC1)
#if (UC_CGM_AC1210_DC1_DIV > UC_CGM_AC1210_DC1_MAX_DIV)
#error AC1210_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC2)
#if (UC_CGM_AC1210_DC2_DIV > UC_CGM_AC1210_DC2_MAX_DIV)
#error AC1210_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC3)
#if (UC_CGM_AC1210_DC3_DIV > UC_CGM_AC1210_DC3_MAX_DIV)
#error AC1210_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC4)
#if (UC_CGM_AC1210_DC4_DIV > UC_CGM_AC1210_DC4_MAX_DIV)
#error AC1210_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1210_DC5)
#if (UC_CGM_AC1210_DC5_DIV > UC_CGM_AC1210_DC5_MAX_DIV)
#error AC1210_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC121 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC121_DC0)
#if (UC_CGM_AC121_DC0_DIV > UC_CGM_AC121_DC0_MAX_DIV)
#error AC121_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC1)
#if (UC_CGM_AC121_DC1_DIV > UC_CGM_AC121_DC1_MAX_DIV)
#error AC121_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC2)
#if (UC_CGM_AC121_DC2_DIV > UC_CGM_AC121_DC2_MAX_DIV)
#error AC121_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC3)
#if (UC_CGM_AC121_DC3_DIV > UC_CGM_AC121_DC3_MAX_DIV)
#error AC121_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC4)
#if (UC_CGM_AC121_DC4_DIV > UC_CGM_AC121_DC4_MAX_DIV)
#error AC121_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC121_DC5)
#if (UC_CGM_AC121_DC5_DIV > UC_CGM_AC121_DC5_MAX_DIV)
#error AC121_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC12 Divider MAX values
 * Dividers must be <= their MAX values
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12_DC0)
#if (UC_CGM_AC12_DC0_DIV > UC_CGM_AC12_DC0_MAX_DIV)
#error AC12_DC0 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC1)
#if (UC_CGM_AC12_DC1_DIV > UC_CGM_AC12_DC1_MAX_DIV)
#error AC12_DC1 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC2)
#if (UC_CGM_AC12_DC2_DIV > UC_CGM_AC12_DC2_MAX_DIV)
#error AC12_DC2 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC3)
#if (UC_CGM_AC12_DC3_DIV > UC_CGM_AC12_DC3_MAX_DIV)
#error AC12_DC3 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC4)
#if (UC_CGM_AC12_DC4_DIV > UC_CGM_AC12_DC4_MAX_DIV)
#error AC12_DC4 Divider is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC5)
#if (UC_CGM_AC12_DC5_DIV > UC_CGM_AC12_DC5_MAX_DIV)
#error AC12_DC5 Divider is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC1 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1_DC0 && UC_CGM_AC1_DC0_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC0_DIV) > UC_CGM_AC1_DC0_MAX_CLOCK)
#error AC1_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC1 && UC_CGM_AC1_DC1_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC1_DIV) > UC_CGM_AC1_DC1_MAX_CLOCK)
#error AC1_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC2 && UC_CGM_AC1_DC2_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC2_DIV) > UC_CGM_AC1_DC2_MAX_CLOCK)
#error AC1_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC3 && UC_CGM_AC1_DC3_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC3_DIV) > UC_CGM_AC1_DC3_MAX_CLOCK)
#error AC1_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC4 && UC_CGM_AC1_DC4_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC4_DIV) > UC_CGM_AC1_DC4_MAX_CLOCK)
#error AC1_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC5 && UC_CGM_AC1_DC5_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC5_DIV) > UC_CGM_AC1_DC5_MAX_CLOCK)
#error AC1_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC1 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC1_DC0 && UC_CGM_AC1_DC0_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC0_DIV) > UC_CGM_AC1_DC0_MAX_CLOCK)
#error AC1_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC1 && UC_CGM_AC1_DC1_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC1_DIV) > UC_CGM_AC1_DC1_MAX_CLOCK)
#error AC1_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC2 && UC_CGM_AC1_DC2_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC2_DIV) > UC_CGM_AC1_DC2_MAX_CLOCK)
#error AC1_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC3 && UC_CGM_AC1_DC3_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC3_DIV) > UC_CGM_AC1_DC3_MAX_CLOCK)
#error AC1_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC4 && UC_CGM_AC1_DC4_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC4_DIV) > UC_CGM_AC1_DC4_MAX_CLOCK)
#error AC1_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC1_DC5 && UC_CGM_AC1_DC5_DIV)
#if ((UC_CGM_AC1_CLOCK_VALUE / UC_CGM_AC1_DC5_DIV) > UC_CGM_AC1_DC5_MAX_CLOCK)
#error AC1_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC2 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC2_DC0 && UC_CGM_AC2_DC0_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC0_DIV) > UC_CGM_AC2_DC0_MAX_CLOCK)
#error AC2_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC1 && UC_CGM_AC2_DC1_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC1_DIV) > UC_CGM_AC2_DC1_MAX_CLOCK)
#error AC2_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC2 && UC_CGM_AC2_DC2_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC2_DIV) > UC_CGM_AC2_DC2_MAX_CLOCK)
#error AC2_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC3 && UC_CGM_AC2_DC3_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC3_DIV) > UC_CGM_AC2_DC3_MAX_CLOCK)
#error AC2_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC4 && UC_CGM_AC2_DC4_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC4_DIV) > UC_CGM_AC2_DC4_MAX_CLOCK)
#error AC2_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC2_DC5 && UC_CGM_AC2_DC5_DIV)
#if ((UC_CGM_AC2_CLOCK_VALUE / UC_CGM_AC2_DC5_DIV) > UC_CGM_AC2_DC5_MAX_CLOCK)
#error AC2_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC3 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC3_DC0 && UC_CGM_AC3_DC0_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC0_DIV) > UC_CGM_AC3_DC0_MAX_CLOCK)
#error AC3_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC1 && UC_CGM_AC3_DC1_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC1_DIV) > UC_CGM_AC3_DC1_MAX_CLOCK)
#error AC3_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC2 && UC_CGM_AC3_DC2_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC2_DIV) > UC_CGM_AC3_DC2_MAX_CLOCK)
#error AC3_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC3 && UC_CGM_AC3_DC3_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC3_DIV) > UC_CGM_AC3_DC3_MAX_CLOCK)
#error AC3_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC4 && UC_CGM_AC3_DC4_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC4_DIV) > UC_CGM_AC3_DC4_MAX_CLOCK)
#error AC3_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC3_DC5 && UC_CGM_AC3_DC5_DIV)
#if ((UC_CGM_AC3_CLOCK_VALUE / UC_CGM_AC3_DC5_DIV) > UC_CGM_AC3_DC5_MAX_CLOCK)
#error AC3_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC4 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC4_DC0 && UC_CGM_AC4_DC0_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC0_DIV) > UC_CGM_AC4_DC0_MAX_CLOCK)
#error AC4_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC1 && UC_CGM_AC4_DC1_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC1_DIV) > UC_CGM_AC4_DC1_MAX_CLOCK)
#error AC4_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC2 && UC_CGM_AC4_DC2_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC2_DIV) > UC_CGM_AC4_DC2_MAX_CLOCK)
#error AC4_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC3 && UC_CGM_AC4_DC3_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC3_DIV) > UC_CGM_AC4_DC3_MAX_CLOCK)
#error AC4_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC4 && UC_CGM_AC4_DC4_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC4_DIV) > UC_CGM_AC4_DC4_MAX_CLOCK)
#error AC4_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC4_DC5 && UC_CGM_AC4_DC5_DIV)
#if ((UC_CGM_AC4_CLOCK_VALUE / UC_CGM_AC4_DC5_DIV) > UC_CGM_AC4_DC5_MAX_CLOCK)
#error AC4_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC5 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC5_DC0 && UC_CGM_AC5_DC0_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC0_DIV) > UC_CGM_AC5_DC0_MAX_CLOCK)
#error AC5_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC1 && UC_CGM_AC5_DC1_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC1_DIV) > UC_CGM_AC5_DC1_MAX_CLOCK)
#error AC5_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC2 && UC_CGM_AC5_DC2_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC2_DIV) > UC_CGM_AC5_DC2_MAX_CLOCK)
#error AC5_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC3 && UC_CGM_AC5_DC3_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC3_DIV) > UC_CGM_AC5_DC3_MAX_CLOCK)
#error AC5_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC4 && UC_CGM_AC5_DC4_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC4_DIV) > UC_CGM_AC5_DC4_MAX_CLOCK)
#error AC5_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC5_DC5 && UC_CGM_AC5_DC5_DIV)
#if ((UC_CGM_AC5_CLOCK_VALUE / UC_CGM_AC5_DC5_DIV) > UC_CGM_AC5_DC5_MAX_CLOCK)
#error AC5_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC6 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC6_DC0 && UC_CGM_AC6_DC0_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC0_DIV) > UC_CGM_AC6_DC0_MAX_CLOCK)
#error AC6_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC1 && UC_CGM_AC6_DC1_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC1_DIV) > UC_CGM_AC6_DC1_MAX_CLOCK)
#error AC6_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC2 && UC_CGM_AC6_DC2_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC2_DIV) > UC_CGM_AC6_DC2_MAX_CLOCK)
#error AC6_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC3 && UC_CGM_AC6_DC3_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC3_DIV) > UC_CGM_AC6_DC3_MAX_CLOCK)
#error AC6_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC4 && UC_CGM_AC6_DC4_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC4_DIV) > UC_CGM_AC6_DC4_MAX_CLOCK)
#error AC6_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC6_DC5 && UC_CGM_AC6_DC5_DIV)
#if ((UC_CGM_AC6_CLOCK_VALUE / UC_CGM_AC6_DC5_DIV) > UC_CGM_AC6_DC5_MAX_CLOCK)
#error AC6_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC7 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC7_DC0 && UC_CGM_AC7_DC0_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC0_DIV) > UC_CGM_AC7_DC0_MAX_CLOCK)
#error AC7_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC1 && UC_CGM_AC7_DC1_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC1_DIV) > UC_CGM_AC7_DC1_MAX_CLOCK)
#error AC7_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC2 && UC_CGM_AC7_DC2_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC2_DIV) > UC_CGM_AC7_DC2_MAX_CLOCK)
#error AC7_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC3 && UC_CGM_AC7_DC3_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC3_DIV) > UC_CGM_AC7_DC3_MAX_CLOCK)
#error AC7_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC4 && UC_CGM_AC7_DC4_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC4_DIV) > UC_CGM_AC7_DC4_MAX_CLOCK)
#error AC7_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC7_DC5 && UC_CGM_AC7_DC5_DIV)
#if ((UC_CGM_AC7_CLOCK_VALUE / UC_CGM_AC7_DC5_DIV) > UC_CGM_AC7_DC5_MAX_CLOCK)
#error AC7_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC8 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC8_DC0 && UC_CGM_AC8_DC0_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC0_DIV) > UC_CGM_AC8_DC0_MAX_CLOCK)
#error AC8_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC1 && UC_CGM_AC8_DC1_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC1_DIV) > UC_CGM_AC8_DC1_MAX_CLOCK)
#error AC8_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC2 && UC_CGM_AC8_DC2_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC2_DIV) > UC_CGM_AC8_DC2_MAX_CLOCK)
#error AC8_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC3 && UC_CGM_AC8_DC3_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC3_DIV) > UC_CGM_AC8_DC3_MAX_CLOCK)
#error AC8_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC4 && UC_CGM_AC8_DC4_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC4_DIV) > UC_CGM_AC8_DC4_MAX_CLOCK)
#error AC8_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC8_DC5 && UC_CGM_AC8_DC5_DIV)
#if ((UC_CGM_AC8_CLOCK_VALUE / UC_CGM_AC8_DC5_DIV) > UC_CGM_AC8_DC5_MAX_CLOCK)
#error AC8_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC9 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC9_DC0 && UC_CGM_AC9_DC0_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC0_DIV) > UC_CGM_AC9_DC0_MAX_CLOCK)
#error AC9_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC1 && UC_CGM_AC9_DC1_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC1_DIV) > UC_CGM_AC9_DC1_MAX_CLOCK)
#error AC9_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC2 && UC_CGM_AC9_DC2_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC2_DIV) > UC_CGM_AC9_DC2_MAX_CLOCK)
#error AC9_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC3 && UC_CGM_AC9_DC3_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC3_DIV) > UC_CGM_AC9_DC3_MAX_CLOCK)
#error AC9_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC4 && UC_CGM_AC9_DC4_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC4_DIV) > UC_CGM_AC9_DC4_MAX_CLOCK)
#error AC9_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC9_DC5 && UC_CGM_AC9_DC5_DIV)
#if ((UC_CGM_AC9_CLOCK_VALUE / UC_CGM_AC9_DC5_DIV) > UC_CGM_AC9_DC5_MAX_CLOCK)
#error AC9_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC10 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC10_DC0 && UC_CGM_AC10_DC0_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC0_DIV) > UC_CGM_AC10_DC0_MAX_CLOCK)
#error AC10_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC1 && UC_CGM_AC10_DC1_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC1_DIV) > UC_CGM_AC10_DC1_MAX_CLOCK)
#error AC10_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC2 && UC_CGM_AC10_DC2_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC2_DIV) > UC_CGM_AC10_DC2_MAX_CLOCK)
#error AC10_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC3 && UC_CGM_AC10_DC3_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC3_DIV) > UC_CGM_AC10_DC3_MAX_CLOCK)
#error AC10_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC4 && UC_CGM_AC10_DC4_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC4_DIV) > UC_CGM_AC10_DC4_MAX_CLOCK)
#error AC10_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC10_DC5 && UC_CGM_AC10_DC5_DIV)
#if ((UC_CGM_AC10_CLOCK_VALUE / UC_CGM_AC10_DC5_DIV) > UC_CGM_AC10_DC5_MAX_CLOCK)
#error AC10_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC11 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC11_DC0 && UC_CGM_AC11_DC0_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC0_DIV) > UC_CGM_AC11_DC0_MAX_CLOCK)
#error AC11_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC1 && UC_CGM_AC11_DC1_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC1_DIV) > UC_CGM_AC11_DC1_MAX_CLOCK)
#error AC11_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC2 && UC_CGM_AC11_DC2_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC2_DIV) > UC_CGM_AC11_DC2_MAX_CLOCK)
#error AC11_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC3 && UC_CGM_AC11_DC3_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC3_DIV) > UC_CGM_AC11_DC3_MAX_CLOCK)
#error AC11_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC4 && UC_CGM_AC11_DC4_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC4_DIV) > UC_CGM_AC11_DC4_MAX_CLOCK)
#error AC11_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC11_DC5 && UC_CGM_AC11_DC5_DIV)
#if ((UC_CGM_AC11_CLOCK_VALUE / UC_CGM_AC11_DC5_DIV) > UC_CGM_AC11_DC5_MAX_CLOCK)
#error AC11_DC5 Clock is > MAX value
#endif
#endif

/* ----------------------------------------------------------------------------
 * AC12 Divider MAX CLOCK check
 * Clocks must be below DC max value
 * --------------------------------------------------------------------------*/

#if (UC_MODULE_CGM_AC12_DC0 && UC_CGM_AC12_DC0_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC0_DIV) > UC_CGM_AC12_DC0_MAX_CLOCK)
#error AC12_DC0 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC1 && UC_CGM_AC12_DC1_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC1_DIV) > UC_CGM_AC12_DC1_MAX_CLOCK)
#error AC12_DC1 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC2 && UC_CGM_AC12_DC2_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC2_DIV) > UC_CGM_AC12_DC2_MAX_CLOCK)
#error AC12_DC2 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC3 && UC_CGM_AC12_DC3_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC3_DIV) > UC_CGM_AC12_DC3_MAX_CLOCK)
#error AC12_DC3 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC4 && UC_CGM_AC12_DC4_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC4_DIV) > UC_CGM_AC12_DC4_MAX_CLOCK)
#error AC12_DC4 Clock is > MAX value
#endif
#endif

#if (UC_MODULE_CGM_AC12_DC5 && UC_CGM_AC12_DC5_DIV)
#if ((UC_CGM_AC12_CLOCK_VALUE / UC_CGM_AC12_DC5_DIV) > UC_CGM_AC12_DC5_MAX_CLOCK)
#error AC12_DC5 Clock is > MAX value
#endif
#endif


#endif /* BSP_HW_INIT_CHECK */
#endif /* UC_SPC574K72_SPEC_H_ */
